﻿Imports Infragistics.Web.Mvc

Public Class HomeController
	Inherits System.Web.Mvc.Controller

	'
	' GET: /Home

	Function Index() As ActionResult

		Dim ds As DataSet = GetEmployDepartmentDataSet()
		Dim model As GridModel = New GridModel()
		SetupManualGrid(model, ds)

		Dim ViewModel As SimpleViewModel = New SimpleViewModel()
		ViewModel.DataSet = ds
		ViewModel.GridModel = model

		Return View(ViewModel)
	End Function

	<GridDataSourceAction>
	Function GetData() As ActionResult
		Return View(GetEmployDepartmentDataSet())
	End Function

#Region "Method 2 Specific Grid Config"
	Private Sub SetupManualGrid(model As GridModel, ds As DataSet)
		model.ID = "ManuallyDefinedGrid"
		model.Width = "100%"

		SetupGridLayouts(model)
		SetupGridColumns(model)

		model.DataSource = ds
		model.DataBind()
	End Sub

	Private Sub SetupGridLayouts(rootGrid As GridModel)
		' Setting as DataMember of the root grid the name of Departments DataTable 
		rootGrid.AutoGenerateColumns = False
		rootGrid.AutoGenerateLayouts = False
		rootGrid.DataMember = "Departments"
		rootGrid.ColumnLayouts = New List(Of IGridModel)

		' Setting as DataMember of the child grid the name of Employees DataTable
		Dim childGrid As GridColumnLayoutModel = New GridColumnLayoutModel()
		childGrid.Key = "Employees"
		childGrid.DataMember = "Employees"
		childGrid.AutoGenerateColumns = False
		childGrid.AutoGenerateLayouts = False
		rootGrid.ColumnLayouts.Add(childGrid)
	End Sub

	Private Sub SetupGridColumns(model As GridModel)
		' Setup our root columns.
		Dim column As GridColumn = New GridColumn()
		column.Key = "DepartmentID"
		column.HeaderText = "DepartmentID"
		column.Hidden = True
		model.Columns.Add(column)

		column = New GridColumn()
		column.Key = "DepartmentName"
		column.HeaderText = "DepartmentName"
		model.Columns.Add(column)

		' Setup our child columns.
		model = model.ColumnLayouts(0)

		column = New GridColumn()
		column.Key = "EmployeeID"
		column.HeaderText = "EmployeeID"
		column.Hidden = True
		model.Columns.Add(column)

		column = New GridColumn()
		column.Key = "Name"
		column.HeaderText = "Name"
		model.Columns.Add(column)

		column = New GridColumn()
		column.Key = "OnSite"
		column.HeaderText = "OnSite"
		column.DataType = "bool"
		model.Columns.Add(column)

		column = New GridColumn()
		column.Key = "DateOfHire"
		column.HeaderText = "DateOfHire"
		column.DataType = "date"
		model.Columns.Add(column)

		column = New GridColumn()
		column.Key = "Department"
		column.HeaderText = "Department"
		column.Hidden = True
		model.Columns.Add(column)
	End Sub
#End Region

#Region "Simple ViewModel"
	Public Class SimpleViewModel
		Private _dataSet As DataSet
		Public Property DataSet() As DataSet
			Get
				Return _dataSet
			End Get
			Set(ByVal value As DataSet)
				_dataSet = value
			End Set
		End Property

		Private _gridModel As GridModel
		Public Property GridModel() As GridModel
			Get
				Return _gridModel
			End Get
			Set(ByVal value As GridModel)
				_gridModel = value
			End Set
		End Property

	End Class
#End Region

#Region "Test Data"
	Public Function GetEmployDepartmentDataSet() As DataSet
		Dim ds As DataSet = New DataSet("EmployeeRecords")

		' Get the tables to use in the DataSet
		Dim Employees As DataTable = Me.GetEmployees()
		Dim Departments As DataTable = Me.GetDepartments()

		' Add the tables to the DataSet
		ds.Tables.Add(Departments)
		ds.Tables.Add(Employees)

		' Create the relationship between the tables.
		ds.Relations.Add("DepartmentEmployee", Departments.Columns("DepartmentID"), Employees.Columns("Department"))
		Return ds
	End Function


	Private Function GetDepartments() As DataTable
		Dim dt As DataTable = New DataTable("Departments")
		dt.Columns.Add("DepartmentID", GetType(Integer))
		dt.Columns.Add("DepartmentName", GetType(String))

		For i As Integer = 0 To 7 Step 1
			dt.Rows.Add(New Object() {i, String.Format("Department {0}", i)})
		Next

		dt.PrimaryKey = New DataColumn() {dt.Columns("DepartmentID")}

		Return dt
	End Function

	Private Function GetEmployees(Optional ByVal count As Integer = 23) As DataTable
		Dim dtData As DataTable = New DataTable("Employees")

		dtData.Columns.Add("EmployeeID", GetType(Integer))
		dtData.Columns.Add("Name", GetType(String))
		dtData.Columns.Add("OnSite", GetType(Boolean))
		dtData.Columns.Add("DateOfHire", GetType(DateTime))
		dtData.Columns.Add("Department", GetType(Integer))

		For i As Integer = 0 To count Step 1
			dtData.Rows.Add(New Object() {i, String.Format("Name {0}", i), (i Mod 2 = 0), DateTime.Today, i Mod 8})
		Next

		dtData.PrimaryKey = New DataColumn() {dtData.Columns("EmployeeID")}

		Return dtData
	End Function
#End Region

#Region "Method 3 Specific Spoofing Data Structure"
	Public Class SpoofDepartment
		Private _departmentID As Integer
		Public Property DepartmentID() As Integer
			Get
				Return _departmentID
			End Get
			Set(ByVal value As Integer)
				_departmentID = value
			End Set
		End Property

		Private _departmentName As String
		Public Property DepartmentName() As String
			Get
				Return _departmentName
			End Get
			Set(ByVal value As String)
				_departmentName = value
			End Set
		End Property
		Private _employees As List(Of SpoofEmployee)
		Public Property Employees() As List(Of SpoofEmployee)
			Get
				Return _employees
			End Get
			Set(ByVal value As List(Of SpoofEmployee))
				_employees = value
			End Set
		End Property

	End Class

	Public Class SpoofEmployee
		Private _employeeID As Integer
		Public Property EmployeeID() As Integer
			Get
				Return _employeeID
			End Get
			Set(ByVal value As Integer)
				_employeeID = value
			End Set
		End Property

		Private _name As String
		Public Property Name() As String
			Get
				Return _name
			End Get
			Set(ByVal value As String)
				_name = value
			End Set
		End Property

		Private _onSite As Boolean
		Public Property OnSite() As Boolean
			Get
				Return _onSite
			End Get
			Set(ByVal value As Boolean)
				_onSite = value
			End Set
		End Property

		Private _dateOfHire As DateTime
		Public Property DateOfHire() As DateTime
			Get
				Return _dateOfHire
			End Get
			Set(ByVal value As DateTime)
				_dateOfHire = value
			End Set
		End Property

		Private _departmentID As Integer
		Public Property DepartmentID() As Integer
			Get
				Return _departmentID
			End Get
			Set(ByVal value As Integer)
				_departmentID = value
			End Set
		End Property

	End Class
#End Region

End Class